ProverState

Struct ProverState 

pub struct ProverState<H = StdHash, R = StdRng>{ /* private fields */ }

Implementations

Source

impl<H> ProverState<H, StdRng>

pub fn new<I>(ds: &DomainSeparator<'_, I>, duplex: H) -> Self
where u8: Encoding<[H::U]>, I: Encoding<[H::U]>,

Construct a new prover state with a custom duplex hash function.

Note. The spongefish API currently does not allow creating an instance with a non-standard random number generator.

Source

impl ProverState<StdHash, StdRng>

pub fn new_std<I>(ds: &DomainSeparator<'_, I>) -> Self
where I: Encoding<[u8]>,

Construct a new prover state with the standard duplex hash function.

Source

impl<H, R> ProverState<H, R>

pub fn rng(&mut self) -> &mut (impl RngCore + CryptoRng)

Access the prover’s private transcript-bound RNG.

pub fn prover_message<T>(&mut self, message: &T)
where T: Encoding<[H::U]> + NargSerialize + ?Sized,

pub fn prover_hint<T>(&mut self, hint: &T)
where T: NargSerialize,

pub fn prover_hint_ark<T>(&mut self, value: &T)

pub fn proof(self) -> Proof